eprllib.RewardFunctions.henderson\_2024
=======================================

.. automodule:: eprllib.RewardFunctions.henderson_2024

   
   .. rubric:: Classes

   .. autosummary::
   
      henderson_2024
   